==> tabula_2.0.0.tar.gz: tabula/R/tabula-package.R <==
#' @details
#' \tabular{ll}{
#'  **Package:** \tab tabula \cr
#'  **Type:** \tab Package \cr
#'  **Version:** \tab 2.0.0 \cr
#'  **License:** \tab GPL-3 \cr
#'  **Zenodo:** \tab \doi{10.5281/zenodo.1489944} \cr
#'  **JOSS:** \tab \doi{10.21105/joss.01821} \cr
#' }
#'
#' @author
#' **Full list of authors and contributors** (alphabetic order)
#'
#' \tabular{ll}{
#'  Jean-Baptiste Fourvel \tab *CNRS, France* \cr
#'  Nicolas Frerebeau \tab *Université Bordeaux Montaigne, France* \cr
#'  Brice Lebrun \tab *Université Bordeaux Montaigne, France* \cr
#'  Ben Marwick \tab *University of Washington, USA* \cr
#'  Matthew Peeples \tab *Arizona State University, USA* \cr
#'  Anne Philippe \tab *Université de Nantes, France* \cr
#' }
#'
#' **Package maintainer**
#'
#' Nicolas Frerebeau\cr
#' \email{nicolas.frerebeau@@u-bordeaux-montaigne.fr}
#'
#' Archéosciences Bordeaux (UMR 6034)\cr
#' Maison de l'Archéologie\cr
#' Université Bordeaux Montaigne\cr
#' 33607 Pessac cedex\cr
#' France
#' @name tabula-package
#' @aliases tabula
#' @docType package
#' @keywords internal
"_PACKAGE"

#' @import arkhe
#' @importFrom ggplot2 ggplot aes coord_fixed element_blank element_rect
#' element_text facet_wrap geom_line geom_path geom_point geom_polygon geom_tile
#' labs scale_size_area scale_x_continuous scale_x_discrete scale_x_log10
#' scale_y_continuous scale_y_discrete scale_y_log10 theme theme_gray waiver
#' @importFrom methods as callNextMethod new setClass setClassUnion setGeneric
#' setMethod validObject .valueClassTest
#' @importFrom rlang .data
#' @importFrom stats sd
NULL

==> tabula_3.2.0.tar.gz: tabula/R/tabula-package.R <==
#' @details
#' \tabular{ll}{
#'  **Package:** \tab tabula \cr
#'  **Type:** \tab Package \cr
#'  **Version:** \tab 3.2.0 \cr
#'  **License:** \tab GPL-3 \cr
#'  **Zenodo:** \tab \doi{10.5281/zenodo.1489944} \cr
#'  **JOSS:** \tab \doi{10.21105/joss.01821} \cr
#' }
#'
#' @section Package options:
#'  \pkg{tabula} uses the following [options()] to configure behavior:
#'  * `tabula.progress`: a [`logical`] scalar. Should progress bars be
#'    displayed? Defaults to [interactive()].
#'  * `tabula.verbose`: a [`logical`] scalar. Should \R report extra information
#'    on progress? Defaults to [interactive()].
#'
#' @author
#' **Full list of authors and contributors** (alphabetic order)
#'
#' \tabular{ll}{
#'  Jean-Baptiste Fourvel \tab *CNRS, France* \cr
#'  Nicolas Frerebeau \tab *Université Bordeaux Montaigne, France* \cr
#'  Brice Lebrun \tab *Université Bordeaux Montaigne, France* \cr
#'  Ben Marwick \tab *University of Washington, USA* \cr
#'  Matthew Peeples \tab *Arizona State University, USA* \cr
#'  Anne Philippe \tab *Université de Nantes, France* \cr
#' }
#'
#' **Package maintainer**
#'
#' Nicolas Frerebeau\cr
#' \email{nicolas.frerebeau@@u-bordeaux-montaigne.fr}
#'
#' Archéosciences Bordeaux (UMR 6034)\cr
#' Maison de l'Archéologie\cr
#' Université Bordeaux Montaigne\cr
#' 33607 Pessac cedex\cr
#' France
#' @name tabula-package
#' @aliases tabula
#' @docType package
#' @keywords internal
"_PACKAGE"

#' @import arkhe
#' @importFrom methods as callGeneric initialize is new setClass setOldClass
#' setGeneric setMethod validObject .valueClassTest
#' @importFrom stats as.dist na.omit pairwise.table pt quantile rmultinom sd
#' @importFrom utils combn head modifyList setTxtProgressBar tail txtProgressBar
NULL
